@@ -1,12 +1,13 @@
 # pylint: disable=redefined-outer-name
 import os
 import sys
+import tempfile
 from glob import glob
 
 import numpy as np
 import pytest
 
-from arviz import from_cmdstanpy
+from ... import from_cmdstanpy
 
 from ..helpers import (  # pylint: disable=unused-import
     chains,
@@ -40,19 +41,22 @@ def _create_test_data():
         parameters {
             real mu;
             real<lower=0> tau;
-            real eta[J];
+            real eta[2, J / 2];
         }
 
         transformed parameters {
             real theta[J];
-            for (j in 1:J)
-                theta[j] = mu + tau * eta[j];
+            for (j in 1:J/2) {
+                theta[j] = mu + tau * eta[1, j];
+                theta[j + 4] = mu + tau * eta[2, j];
+            }
         }
 
         model {
             mu ~ normal(0, 5);
             tau ~ cauchy(0, 5);
-            eta ~ normal(0, 1);
+            eta[1] ~ normal(0, 1);
+            eta[2] ~ normal(0, 1);
             y ~ normal(theta, sigma);
         }
 
@@ -66,7 +70,7 @@ def _create_test_data():
         }
     """
     stan_file = "stan_test_data.stan"
-    with open(stan_file, "w") as file_handle:
+    with open(stan_file, "w", encoding="utf8") as file_handle:
         print(model_code, file=file_handle)
     model = cmdstanpy.CmdStanModel(stan_file=stan_file)
     os.remove(stan_file)
@@ -131,6 +135,7 @@ class TestDataCmdStanPy:
     def data(self, filepaths):
         # Skip tests if cmdstanpy not installed
         cmdstanpy = importorskip("cmdstanpy")
+        CmdStanModel = cmdstanpy.CmdStanModel  # pylint: disable=invalid-name
         CmdStanMCMC = cmdstanpy.CmdStanMCMC  # pylint: disable=invalid-name
         RunSet = cmdstanpy.stanfit.RunSet  # pylint: disable=invalid-name
         CmdStanArgs = cmdstanpy.model.CmdStanArgs  # pylint: disable=invalid-name
@@ -146,7 +151,6 @@ class TestDataCmdStanPy:
             runset_obj = RunSet(args)
             runset_obj._csv_files = filepaths["nowarmup"]  # pylint: disable=protected-access
             obj = CmdStanMCMC(runset_obj)
-            obj.validate_csv_files()  # pylint: disable=protected-access
             obj._assemble_draws()  # pylint: disable=protected-access
 
             args_warmup = CmdStanArgs(
@@ -158,9 +162,15 @@ class TestDataCmdStanPy:
             runset_obj_warmup = RunSet(args_warmup)
             runset_obj_warmup._csv_files = filepaths["warmup"]  # pylint: disable=protected-access
             obj_warmup = CmdStanMCMC(runset_obj_warmup)
-            obj_warmup.validate_csv_files()  # pylint: disable=protected-access
             obj_warmup._assemble_draws()  # pylint: disable=protected-access
 
+            _model_code = """model { real y; } generated quantities { int eta; int theta[N]; }"""
+            _tmp_dir = tempfile.TemporaryDirectory(prefix="arviz_tests_")
+            _stan_file = os.path.join(_tmp_dir.name, "stan_model_test.stan")
+            with open(_stan_file, "w", encoding="utf8") as f:
+                f.write(_model_code)
+            model = CmdStanModel(stan_file=_stan_file, compile=False)
+
         return Data
 
     def get_inference_data(self, data, eight_schools_params):
@@ -174,14 +184,13 @@ class TestDataCmdStanPy:
             observed_data={"y": eight_schools_params["y"]},
             constant_data={"y": eight_schools_params["y"]},
             predictions_constant_data={"y": eight_schools_params["y"]},
-            log_likelihood="log_lik",
+            log_likelihood={"y": "log_lik"},
             coords={"school": np.arange(eight_schools_params["J"])},
             dims={
-                "theta": ["school"],
                 "y": ["school"],
                 "log_lik": ["school"],
                 "y_hat": ["school"],
-                "eta": ["school"],
+                "theta": ["school"],
             },
         )
 
@@ -202,10 +211,10 @@ class TestDataCmdStanPy:
                 "log_lik_dim": np.arange(eight_schools_params["J"]),
             },
             dims={
-                "theta": ["school"],
+                "eta": ["extra_dim", "half school"],
                 "y": ["school"],
                 "y_hat": ["school"],
-                "eta": ["school"],
+                "theta": ["school"],
                 "log_lik": ["log_lik_dim"],
             },
         )
@@ -218,8 +227,19 @@ class TestDataCmdStanPy:
             prior=data.obj,
             prior_predictive=["y_hat", "log_lik"],
             observed_data={"y": eight_schools_params["y"]},
-            coords={"school": np.arange(eight_schools_params["J"])},
-            dims={"theta": ["school"], "y": ["school"], "y_hat": ["school"], "eta": ["school"]},
+            coords={
+                "school": np.arange(eight_schools_params["J"]),
+                "half school": ["a", "b", "c", "d"],
+                "extra_dim": ["x", "y"],
+            },
+            dims={
+                "eta": ["extra_dim", "half school"],
+                "y": ["school"],
+                "y_hat": ["school"],
+                "theta": ["school"],
+                "log_lik": ["log_lik_dim"],
+            },
+            dtypes=data.model,
         )
 
     def get_inference_data4(self, data, eight_schools_params):
@@ -229,9 +249,25 @@ class TestDataCmdStanPy:
             posterior_predictive=None,
             prior=data.obj,
             prior_predictive=None,
+            log_likelihood=False,
             observed_data={"y": eight_schools_params["y"]},
             coords=None,
             dims=None,
+            dtypes={"eta": int, "theta": int},
+        )
+
+    def get_inference_data5(self, data, eight_schools_params):
+        """multiple vars as lists."""
+        return from_cmdstanpy(
+            posterior=data.obj,
+            posterior_predictive=None,
+            prior=data.obj,
+            prior_predictive=None,
+            log_likelihood="log_lik",
+            observed_data={"y": eight_schools_params["y"]},
+            coords=None,
+            dims=None,
+            dtypes=data.model.code(),
         )
 
     def get_inference_data_warmup_true_is_true(self, data, eight_schools_params):
@@ -248,11 +284,11 @@ class TestDataCmdStanPy:
             log_likelihood="log_lik",
             coords={"school": np.arange(eight_schools_params["J"])},
             dims={
-                "theta": ["school"],
+                "eta": ["extra_dim", "half school"],
                 "y": ["school"],
                 "log_lik": ["school"],
                 "y_hat": ["school"],
-                "eta": ["school"],
+                "theta": ["school"],
             },
             save_warmup=True,
         )
@@ -271,11 +307,11 @@ class TestDataCmdStanPy:
             log_likelihood="log_lik",
             coords={"school": np.arange(eight_schools_params["J"])},
             dims={
-                "theta": ["school"],
+                "eta": ["extra_dim", "half school"],
                 "y": ["school"],
                 "log_lik": ["school"],
                 "y_hat": ["school"],
-                "eta": ["school"],
+                "theta": ["school"],
             },
             save_warmup=True,
         )
@@ -294,11 +330,11 @@ class TestDataCmdStanPy:
             log_likelihood="log_lik",
             coords={"school": np.arange(eight_schools_params["J"])},
             dims={
-                "theta": ["school"],
+                "eta": ["extra_dim", "half school"],
                 "y": ["school"],
                 "log_lik": ["school"],
                 "y_hat": ["school"],
-                "eta": ["school"],
+                "theta": ["school"],
             },
             save_warmup=False,
         )
@@ -315,6 +351,8 @@ class TestDataCmdStanPy:
         inference_data2 = self.get_inference_data2(data, eight_schools_params)
         inference_data3 = self.get_inference_data3(data, eight_schools_params)
         inference_data4 = self.get_inference_data4(data, eight_schools_params)
+        inference_data5 = self.get_inference_data5(data, eight_schools_params)
+
         # inference_data 1
         test_dict = {
             "posterior": ["theta"],
@@ -322,11 +360,12 @@ class TestDataCmdStanPy:
             "observed_data": ["y"],
             "constant_data": ["y"],
             "predictions_constant_data": ["y"],
-            "log_likelihood": ["log_lik"],
+            "log_likelihood": ["y", "~log_lik"],
             "prior": ["theta"],
         }
         fails = check_multiple_attrs(test_dict, inference_data1)
         assert not fails
+
         # inference_data 2
         test_dict = {
             "posterior_predictive": ["y_hat"],
@@ -341,6 +380,7 @@ class TestDataCmdStanPy:
         }
         fails = check_multiple_attrs(test_dict, inference_data2)
         assert not fails
+
         # inference_data 3
         test_dict = {
             "posterior_predictive": ["y_hat"],
@@ -348,15 +388,36 @@ class TestDataCmdStanPy:
             "sample_stats_prior": ["lp"],
             "sample_stats": ["lp"],
             "prior_predictive": ["y_hat"],
+            "log_likelihood": ["log_lik"],
         }
         fails = check_multiple_attrs(test_dict, inference_data3)
         assert not fails
+        assert inference_data3.posterior.eta.dtype.kind == "i"  # pylint: disable=no-member
+        assert inference_data3.posterior.theta.dtype.kind == "i"  # pylint: disable=no-member
+
         # inference_data 4
-        test_dict = {"posterior": ["theta"], "prior": ["theta"]}
+        test_dict = {
+            "posterior": ["eta", "mu", "theta"],
+            "prior": ["theta"],
+            "~log_likelihood": [""],
+        }
         fails = check_multiple_attrs(test_dict, inference_data4)
         assert not fails
         assert len(inference_data4.posterior.theta.shape) == 3  # pylint: disable=no-member
+        assert len(inference_data4.posterior.eta.shape) == 4  # pylint: disable=no-member
         assert len(inference_data4.posterior.mu.shape) == 2  # pylint: disable=no-member
+        assert inference_data4.posterior.eta.dtype.kind == "i"  # pylint: disable=no-member
+        assert inference_data4.posterior.theta.dtype.kind == "i"  # pylint: disable=no-member
+
+        # inference_data 5
+        test_dict = {
+            "posterior": ["eta", "mu", "theta"],
+            "prior": ["theta"],
+            "log_likelihood": ["log_lik"],
+        }
+        fails = check_multiple_attrs(test_dict, inference_data5)
+        assert inference_data5.posterior.eta.dtype.kind == "i"  # pylint: disable=no-member
+        assert inference_data5.posterior.theta.dtype.kind == "i"  # pylint: disable=no-member
 
     def test_inference_data_warmup(self, data, eight_schools_params):
         inference_data_true_is_true = self.get_inference_data_warmup_true_is_true(
@@ -394,13 +455,13 @@ class TestDataCmdStanPy:
             "predictions_constant_data": ["y"],
             "log_likelihood": ["log_lik"],
             "prior": ["theta"],
+            "~warmup_posterior": [""],
+            "~warmup_predictions": [""],
+            "~warmup_log_likelihood": [""],
+            "~warmup_prior": [""],
         }
         fails = check_multiple_attrs(test_dict, inference_data_false_is_true)
         assert not fails
-        assert "warmup_posterior" not in inference_data_false_is_true
-        assert "warmup_predictions" not in inference_data_false_is_true
-        assert "warmup_log_likelihood" not in inference_data_false_is_true
-        assert "warmup_prior" not in inference_data_false_is_true
         # inference_data no warmup
         test_dict = {
             "posterior": ["theta"],
@@ -410,13 +471,13 @@ class TestDataCmdStanPy:
             "predictions_constant_data": ["y"],
             "log_likelihood": ["log_lik"],
             "prior": ["theta"],
+            "~warmup_posterior": [""],
+            "~warmup_predictions": [""],
+            "~warmup_log_likelihood": [""],
+            "~warmup_prior": [""],
         }
         fails = check_multiple_attrs(test_dict, inference_data_true_is_false)
         assert not fails
-        assert "warmup_posterior" not in inference_data_true_is_false
-        assert "warmup_predictions" not in inference_data_true_is_false
-        assert "warmup_log_likelihood" not in inference_data_true_is_false
-        assert "warmup_prior" not in inference_data_true_is_false
         # inference_data no warmup
         test_dict = {
             "posterior": ["theta"],
@@ -424,14 +485,12 @@ class TestDataCmdStanPy:
             "observed_data": ["y"],
             "constant_data": ["y"],
             "predictions_constant_data": ["y"],
-            "log_likelihood": ["log_lik"],
+            "log_likelihood": ["y"],
             "prior": ["theta"],
+            "~warmup_posterior": [""],
+            "~warmup_predictions": [""],
+            "~warmup_log_likelihood": [""],
+            "~warmup_prior": [""],
         }
         fails = check_multiple_attrs(test_dict, inference_data_false_is_false)
         assert not fails
-        assert "warmup_posterior" not in inference_data_false_is_false
-        assert "warmup_predictions" not in inference_data_false_is_false
-        assert "warmup_log_likelihood" not in inference_data_false_is_false
-        assert (
-            "warmup_prior" not in inference_data_false_is_false
-        )  # pylint: disable=redefined-outer-name
